use std::sync::Arc;

use anyhow::Result;

pub mod minecraft;
#[cfg(feature = "sync")]
pub mod sync;

pub(crate) static BASE_URI: &str = "https://playerdb.co/api/player";
pub(crate) static APP_USER_AGENT: &str =
	concat!(env!("CARGO_PKG_NAME"), "/", env!("CARGO_PKG_VERSION"),);

pub struct PlayerDBApi {
	agent: Arc<reqwest::Client>,
}

impl Default for PlayerDBApi {
	fn default() -> Self {
		Self {
			agent: Arc::new(
				reqwest::Client::builder()
					.user_agent(APP_USER_AGENT)
					.build()
					.expect("creating reqwest client"),
			),
		}
	}
}

impl PlayerDBApi {
	pub async fn get_minecraft_player(
		&self,
		player_id: &str,
	) -> Result<minecraft::MinecraftResponse> {
		let url = format!("{}{}/{}", BASE_URI, minecraft::PLATFORM, player_id);
		let res = self
			.agent
			.get(url)
			.send()
			.await?
			.json::<minecraft::MinecraftResponse>()
			.await?;

		Ok(res)
	}
}
