use std::sync::Arc;

use anyhow::Result;

use crate::{minecraft, APP_USER_AGENT, BASE_URI};

pub struct PlayerDBApi {
	agent: Arc<reqwest::blocking::Client>,
}

impl Default for PlayerDBApi {
	fn default() -> Self {
		Self {
			agent: Arc::new(
				reqwest::blocking::Client::builder()
					.user_agent(APP_USER_AGENT)
					.build()
					.expect("creating reqwest client"),
			),
		}
	}
}

impl PlayerDBApi {
	pub fn get_minecraft_player(&self, player_id: &str) -> Result<minecraft::MinecraftResponse> {
		let url = format!("{}{}/{}", BASE_URI, minecraft::PLATFORM, player_id);
		let res = self
			.agent
			.get(url)
			.send()?
			.json::<minecraft::MinecraftResponse>()?;

		Ok(res)
	}
}
